import base64

def get_fixterm():
	fixterm_b64 = '''f0VMRgIBAQAAAAAAAAAAAAIAPgABAAAAsAZAAAAAAABAAAAAAAAAAEgsAAAAAAAAAAAAAEAAOAAJ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'''
	fixterm = base64.b64decode(fixterm_b64)
	return fixterm
